==> hazelcast-5.1-sources.jar: com/hazelcast/client/impl/ClientEndpointStatistics.java <==
/*
 * Copyright (c) 2008-2022, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.client.impl;

import com.hazelcast.internal.util.counters.MwCounter;

import java.util.Collections;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;

import static com.hazelcast.internal.util.SetUtil.createHashSet;

/**
 * Class to hold necessary statistics for the client endpoints.
 * It is created per client type.
 */
public class ClientEndpointStatistics {

    private final MwCounter connectionsOpened = MwCounter.newMwCounter();
    private final MwCounter connectionsClosed = MwCounter.newMwCounter();
    private final MwCounter totalConnectionDuration = MwCounter.newMwCounter();
    private final Set<String> clientVersions = Collections.newSetFromMap(new ConcurrentHashMap<>());

    public void incrementConnectionsOpenedCount() {
        connectionsOpened.inc();
    }

    public void incrementConnectionsClosedCount() {
        connectionsClosed.inc();
    }

    public void incrementTotalConnectionDuration(long duration) {
        totalConnectionDuration.inc(duration);
    }

    public void addClientVersion(String clientVersion) {
        clientVersions.add(clientVersion);
    }

    public ClientEndpointStatisticsSnapshot getSnapshotAndReset() {
        // Operation below is not atomic, there might be new versions
        // added between addAll and clear, but we are fine with that.
        // If we clear more than we copy, the same client version will
        // most likely be added later.
        Set<String> clientVersionsSnapshot = createHashSet(clientVersions.size());
        clientVersionsSnapshot.addAll(clientVersions);
        clientVersions.clear();

        return new ClientEndpointStatisticsSnapshot(
                connectionsOpened.getAndSet(0),
                connectionsClosed.getAndSet(0),
                totalConnectionDuration.getAndSet(0),
                clientVersionsSnapshot
        );
    }

}

==> hazelcast-5.6.0-sources.jar: com/hazelcast/client/impl/ClientEndpointStatistics.java <==
/*
 * Copyright (c) 2008-2025, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.client.impl;

import com.hazelcast.internal.util.counters.MwCounter;

import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;

import static com.hazelcast.internal.util.SetUtil.createHashSet;

/**
 * Class to hold necessary statistics for the client endpoints.
 * It is created per client type.
 */
public class ClientEndpointStatistics {

    private final MwCounter connectionsOpened = MwCounter.newMwCounter();
    private final MwCounter connectionsClosed = MwCounter.newMwCounter();
    private final MwCounter totalConnectionDuration = MwCounter.newMwCounter();
    private final Set<String> clientVersions = ConcurrentHashMap.newKeySet();

    public void incrementConnectionsOpenedCount() {
        connectionsOpened.inc();
    }

    public void incrementConnectionsClosedCount() {
        connectionsClosed.inc();
    }

    public void incrementTotalConnectionDuration(long duration) {
        totalConnectionDuration.inc(duration);
    }

    public void addClientVersion(String clientVersion) {
        clientVersions.add(clientVersion);
    }

    public ClientEndpointStatisticsSnapshot getSnapshotAndReset() {
        // Operation below is not atomic, there might be new versions
        // added between addAll and clear, but we are fine with that.
        // If we clear more than we copy, the same client version will
        // most likely be added later.
        Set<String> clientVersionsSnapshot = createHashSet(clientVersions.size());
        clientVersionsSnapshot.addAll(clientVersions);
        clientVersions.clear();

        return new ClientEndpointStatisticsSnapshot(
                connectionsOpened.getAndSet(0),
                connectionsClosed.getAndSet(0),
                totalConnectionDuration.getAndSet(0),
                clientVersionsSnapshot
        );
    }

}
